@@ -45,15 +45,28 @@ def product_details_tech_spec(selector: parsel.Selector, *fields) -> str:
 
 def parse(html: str, p: Product, include: Sequence = None):
     include = include or Product.__fields__.keys()
+
+    def should_price():
+        return "price_min" in include or "price_max" in include
+
+    def should_ship_day():
+        return "ship_day_min" in include or "ship_day_max" in include
+
+    def should_size():
+        return "size_length" in include or "size_width" in include or "size_height" in include
+
+    def should_variation():
+        return "variation_values" in include or "selected_variations" in include or "asin_variation_values" in include
+
     sel = parsel.Selector(text=html)
     "product_asin" in include and parse_product_asin(p, selector=sel)
     "parent_asin" in include and parse_parent_asin(p, selector=sel)
     "weight" in include and parse_weight(p, selector=sel)
     "brand" in include and parse_brand(p, selector=sel)
-    "price" in include and parse_price(p, selector=sel)
+    should_price() and parse_price(p, selector=sel)
     "in_stock" in include and parse_in_stock(p, selector=sel)
     "stock" in include and parse_stock(p, selector=sel)
-    "ship_day" in include and parse_ship_day(p, selector=sel)
+    should_ship_day() and parse_ship_day(p, selector=sel)
     "ship" in include and parse_ship(p, selector=sel)
     "sold" in include and parse_sold(p, selector=sel)
     "offers" in include and parse_offers(p, selector=sel)
@@ -61,9 +74,9 @@ def parse(html: str, p: Product, include: Sequence = None):
     "material" in include and parse_material(p, selector=sel)
     "description" in include and parse_description(p, selector=sel)
     "title" in include and parse_title(p, selector=sel)
-    "size" in include and parse_size(p, selector=sel)
+    should_size() and parse_size(p, selector=sel)
     "color" in include and parse_color(p, selector=sel)
-    "variation" in include and parse_variation(p, selector=sel)
+    should_variation() and parse_variation(p, selector=sel)
     "review_amount" in include and parse_review_amount(p, selector=sel)
     "review_star" in include and parse_review_star(p, selector=sel)
     "rank" in include and parse_rank(p, selector=sel)
@@ -132,7 +145,6 @@ def parse_price(p: Product, selector: parsel.Selector = None):
 
     def s1() -> str:
         s = selector.xpath("//span[@id='priceblock_ourprice']/text()").get()
-        s = s or selector.xpath("//span[@id='priceblock_saleprice']/text()").get()
         s = s or selector.xpath("//div[@id='buyNew_noncbb']/span/text()").get()
         s = s or selector.xpath("//*[@id='color_name_0_price']/span/text()[last()]").get()
         return s or ""
@@ -141,12 +153,10 @@ def parse_price(p: Product, selector: parsel.Selector = None):
         t = price_table()
         if numpy.all(t["price"] == ""):
             return ""
-        if numpy.any(t["price"] == ""):
+        elif numpy.any(t["price"] == ""):
             return str(t["price"][t["price"] != ""][0])
-        if t.at["discount", "title"] == "Deal of the Day:":
-            return str(t.at["origin", "price"])
         else:
-            return str(t.at["discount", "price"])
+            return str(t.at["origin", "price"])
 
     prices_str = s1() or s2()
     prices: Union[None, list] = parse_number(prices_str.replace(",", ""), first=False)
